package parser

// safeCmds is a list of all the functions considered safe when using tab
// autocomplete with ExecCmdline
var safeCmds = []string{
	"!",
	"![",
	"!and",
	"!escape",
	"!eschtml",
	"!escurl",
	"!match",
	"!or",
	"!regexp",
	"!while",
	"(",
	"2darray",
	"=",
	"[",
	"[[",
	"a",
	"alter",
	"and",
	"append",
	"args",
	"bexists",
	"cast",
	"catch",
	"count",
	"cpuarch",
	"cpucount",
	"debug",
	"escape",
	"esccli",
	"eschtml",
	"escurl",
	"exitnum",
	"f",
	"false",
	"fid-list",
	"for",
	"foreach",
	"formap",
	"format",
	"g",
	"get",
	"get-type",
	"getfile",
	"history",
	"if",
	"ja",
	"jsplit",
	"left",
	"man-summary",
	"map",
	"match",
	"msort",
	"mtac",
	"murex-docs",
	"murex-parser",
	"null",
	"open",
	"open-image",
	"or",
	"os",
	"out",
	"prefix",
	"prepend",
	"pretty",
	"rand",
	"regexp",
	"right",
	"runtime",
	"rx",
	"struct-keys",
	"suffix",
	"swivel-datatype",
	"swivel-table",
	"ta",
	"tabulate",
	"time",
	"tout",
	"true",
	"try",
	"trypipe",
	"version",
	"while",
}
